<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../forms/aboutdialog.ui" line="14"/>
        <source>About Qmmp</source>
        <translation>O Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="40"/>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="54"/>
        <source>Authors</source>
        <translation>Autoři</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="82"/>
        <source>Thanks To</source>
        <translation>Poděkování</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="96"/>
        <source>License Agreement</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="61"/>
        <source>:/txt/authors_en.txt</source>
        <translation>:/txt/authors_cs.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="62"/>
        <source>:/txt/thanks_en.txt</source>
        <translation>:/txt/thanks_cs.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="81"/>
        <source>Qt-based Multimedia Player (Qmmp)</source>
        <translation>Qt-based Multimedia Player (Qmmp)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="82"/>
        <source>Version:</source>
        <translation>Verze:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="83"/>
        <source>:txt/description_en.txt</source>
        <translation>:txt/description_cs.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="84"/>
        <source>Input plugins:</source>
        <translation>Vstupní moduly:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>Output plugins:</source>
        <translation>Výstupní moduly:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="102"/>
        <source>Visual plugins:</source>
        <translation>Vizualizační moduly:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="111"/>
        <source>Effect plugins:</source>
        <translation>Efektové moduly:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="120"/>
        <source>General plugins:</source>
        <translation>Obecné moduly:</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="68"/>
        <source>Translators</source>
        <translation>Překladatelé</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>:/txt/translators_en.txt</source>
        <translation>:/txt/translators_cs.txt</translation>
    </message>
</context>
<context>
    <name>ActionManager</name>
    <message>
        <location filename="../actionmanager.cpp" line="37"/>
        <source>&amp;Play</source>
        <translation type="unfinished">Pře&amp;hrát</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="37"/>
        <source>X</source>
        <translation type="unfinished">X</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>&amp;Pause</source>
        <translation type="unfinished">Pau&amp;za</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>C</source>
        <translation type="unfinished">C</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>&amp;Stop</source>
        <translation type="unfinished">&amp;Stop</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>V</source>
        <translation type="unfinished">V</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>&amp;Previous</source>
        <translation type="unfinished">&amp;Předchozí</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>Z</source>
        <translation type="unfinished">Z</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>&amp;Next</source>
        <translation type="unfinished">&amp;Další</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>B</source>
        <translation type="unfinished">B</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>&amp;Play/Pause</source>
        <translation type="unfinished">&amp;Přehrát/Pauza</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>Space</source>
        <translation type="unfinished">Mezerník</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>&amp;Jump to File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>J</source>
        <translation type="unfinished">J</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>&amp;Repeat Playlist</source>
        <translation type="unfinished">&amp;Opakovat seznam skladeb</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>R</source>
        <translation type="unfinished">O</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>&amp;Repeat Track</source>
        <translation type="unfinished">&amp;Opakovat stopu</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>Ctrl+R</source>
        <translation type="unfinished">Ctrl+R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>&amp;Shuffle</source>
        <translation type="unfinished">Za&amp;míchat</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>S</source>
        <translation type="unfinished">M</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>&amp;No Playlist Advance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="48"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="49"/>
        <source>&amp;Stop After Selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="50"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>&amp;Clear Queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>Alt+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="53"/>
        <source>Show Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="53"/>
        <source>Alt+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Show Equalizer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Alt+G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Always on Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="56"/>
        <source>Put on All Workspaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Double Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Meta+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="59"/>
        <source>&amp;Add File</source>
        <translation type="unfinished">Přidat &amp;soubor</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="59"/>
        <source>F</source>
        <translation type="unfinished">F</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>&amp;Add Directory</source>
        <translation type="unfinished">Přidat &amp;adresář</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>D</source>
        <translation type="unfinished">D</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>&amp;Add Url</source>
        <translation type="unfinished">Přidat &amp;URL</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>U</source>
        <translation type="unfinished">U</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>&amp;Remove Selected</source>
        <translation type="unfinished">&amp;Odstranit vybrané</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="63"/>
        <source>Del</source>
        <translation type="unfinished">Del</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="64"/>
        <source>&amp;Remove All</source>
        <translation type="unfinished">Odstranit &amp;vše</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="65"/>
        <source>&amp;Remove Unselected</source>
        <translation type="unfinished">Odstranit &amp;nevybrané</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="67"/>
        <source>Remove unavailable files</source>
        <translation type="unfinished">Odstranit nedostupné soubory</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="69"/>
        <source>Remove duplicates</source>
        <translation type="unfinished">Odstranit duplicity</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>&amp;Queue Toggle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>Q</source>
        <translation type="unfinished">Q</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>Invert Selection</source>
        <translation type="unfinished">Invertovat výběr</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="72"/>
        <source>&amp;Select None</source>
        <translation type="unfinished">&amp;Zrušit výběr</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="73"/>
        <source>&amp;Select All</source>
        <translation type="unfinished">&amp;Vybrat vše</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="74"/>
        <source>Ctrl+A</source>
        <translation type="unfinished">Ctrl+A</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>&amp;View Track Details</source>
        <translation type="unfinished">Zobrazit &amp;informace o skladbě</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>Alt+I</source>
        <translation type="unfinished">Alt+I</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="77"/>
        <source>&amp;New List</source>
        <translation type="unfinished">&amp;Nový seznam</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="77"/>
        <source>Ctrl+T</source>
        <translation type="unfinished">Ctrl+T</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>&amp;Delete List</source>
        <translation type="unfinished">O&amp;dstranit seznam</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>Ctrl+W</source>
        <translation type="unfinished">Ctrl+W</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>&amp;Load List</source>
        <translation type="unfinished">Načíst &amp;seznam</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>O</source>
        <translation type="unfinished">O</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>&amp;Save List</source>
        <translation type="unfinished">&amp;Uložit seznam</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>Shift+S</source>
        <translation type="unfinished">Shift+S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>&amp;Select Next Playlist</source>
        <translation type="unfinished">Vybrat další &amp;seznam skladeb</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="82"/>
        <source>Ctrl+PgDown</source>
        <translation type="unfinished">Ctrl+PgDown</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="83"/>
        <source>&amp;Select Previous Playlist</source>
        <translation type="unfinished">Vybrat předchozí &amp;seznam skladeb</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="84"/>
        <source>Ctrl+PgUp</source>
        <translation type="unfinished">Ctrl+PgUp</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="85"/>
        <source>&amp;Show Playlists</source>
        <translation type="unfinished">Zobrazit &amp;seznamy skladeb</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="86"/>
        <source>P</source>
        <translation type="unfinished">P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="88"/>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Nastavení</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="88"/>
        <source>Ctrl+P</source>
        <translation type="unfinished">Ctrl+P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>&amp;About</source>
        <translation type="unfinished">O &amp;aplikaci</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>&amp;About Qt</source>
        <translation type="unfinished">O knihovně &amp;Qt</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>&amp;Exit</source>
        <translation type="unfinished">U&amp;končit</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished">Ctrl+Q</translation>
    </message>
</context>
<context>
    <name>AddUrlDialog</name>
    <message>
        <location filename="../forms/addurldialog.ui" line="13"/>
        <source>Enter URL to add</source>
        <translation>Přidat URL</translation>
    </message>
    <message>
        <location filename="../addurldialog.cpp" line="117"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="51"/>
        <source>&amp;Add</source>
        <translation>Přid&amp;at</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="58"/>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
</context>
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="61"/>
        <source>Skip forward in playlist</source>
        <translation>Přejít vpřed v seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="62"/>
        <source>Skip backwards in playlist</source>
        <translation>Přejít zpět v seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="55"/>
        <source>Start playing current song</source>
        <translation>Spustit přehrávání aktuální skladby</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="54"/>
        <source>Don&apos;t clear the playlist</source>
        <translation type="unfinished">Nevyprazdňovat seznam skladeb</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="56"/>
        <source>Pause current song</source>
        <translation>Pozastavit aktuální skladbu</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="57"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pozastavit, přehrává-li se, jinak přehrávat</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="58"/>
        <source>Stop current song</source>
        <translation>Zastavit aktuální skladbu</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="59"/>
        <source>Display Jump to File dialog</source>
        <translation>Zobrazit dialog Přeskočit na soubor</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="60"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Nastavit hlasitost přehrávání (příklad: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="63"/>
        <source>Show/hide application</source>
        <translation>Zobrazit/skrýt aplikaci</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="64"/>
        <source>Display Add File dialog</source>
        <translation>Zobrazit dialog Přidat soubor</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="65"/>
        <source>Display Add Directory dialog</source>
        <translation>Zobrazit dialog Přidat adresář</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../forms/configdialog.ui" line="735"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="740"/>
        <source>Filename</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="429"/>
        <source>Artist</source>
        <translation>Umělec</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="75"/>
        <location filename="../configdialog.cpp" line="430"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="74"/>
        <source>Track</source>
        <translation>Stopa</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="76"/>
        <source>Disabled</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="244"/>
        <source>Transports</source>
        <translation>Protokoly</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="255"/>
        <source>Decoders</source>
        <translation>Dekodéry</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="265"/>
        <source>Engines</source>
        <translation>Přehrávače</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="372"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="431"/>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="432"/>
        <source>Track number</source>
        <translation>Číslo stopy</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="433"/>
        <source>Two-digit track number</source>
        <translation>Dvoumístné číslo stopy</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="437"/>
        <source>Disc number</source>
        <translation>Číslo disku</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="441"/>
        <source>Condition</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="436"/>
        <source>Composer</source>
        <translation>Skladatel</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="438"/>
        <source>File name</source>
        <translation>Název souboru</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="439"/>
        <source>File path</source>
        <translation>Cesta k souboru</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="434"/>
        <source>Genre</source>
        <translation>Žánr</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="440"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="435"/>
        <source>Comment</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="14"/>
        <source>Qmmp Settings</source>
        <translation>Nastavení Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="98"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="107"/>
        <location filename="../forms/configdialog.ui" line="463"/>
        <location filename="../configdialog.cpp" line="366"/>
        <source>Playlist</source>
        <translation>Seznam skladeb</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="116"/>
        <source>Plugins</source>
        <translation>Moduly</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="125"/>
        <source>Advanced</source>
        <translation>Pokročilé</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="184"/>
        <source>Skins</source>
        <translation>Témata</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="291"/>
        <source>Fonts</source>
        <translation>Písma</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="309"/>
        <source>Player:</source>
        <translation>Přehrávač:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="357"/>
        <source>Playlist:</source>
        <translation>Seznam skladeb:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="331"/>
        <location filename="../forms/configdialog.ui" line="379"/>
        <source>???</source>
        <translation>???</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1001"/>
        <source>Replay Gain</source>
        <translation>Zisk při přehrávání</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="249"/>
        <source>Miscellaneous</source>
        <translation>Různé</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="338"/>
        <location filename="../forms/configdialog.ui" line="386"/>
        <location filename="../forms/configdialog.ui" line="552"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="393"/>
        <source>Use bitmap font if available</source>
        <translation>Použít bitmapové písmo, je-li dostupné</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="275"/>
        <source>Use skin cursors</source>
        <translation>Použít kurzory z tématu</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="152"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="511"/>
        <source>Metadata</source>
        <translation>Metadata</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="523"/>
        <source>Load metadata from files</source>
        <translation>Číst ze souborů metadata</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="533"/>
        <source>Song Display</source>
        <translation>Zobrazení skladby</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="539"/>
        <source>Title format:</source>
        <translation>Formát titulku:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="580"/>
        <source>Show song numbers</source>
        <translation>Zobrazit čísla skladeb</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="587"/>
        <source>Show playlists</source>
        <translation>Zobrazit seznam skladeb</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="596"/>
        <source>Show popup information</source>
        <translation>Zobrazit informace ve vyskakovacím okně</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="628"/>
        <source>Show anchor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="638"/>
        <source>Align song numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="686"/>
        <location filename="../forms/configdialog.ui" line="1153"/>
        <source>Preferences</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="699"/>
        <location filename="../forms/configdialog.ui" line="761"/>
        <location filename="../forms/configdialog.ui" line="1166"/>
        <source>Information</source>
        <translation>Informace</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="784"/>
        <source>Cover Image Retrieve</source>
        <translation>Získat obrázek obalu</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="790"/>
        <source>Use separate image files</source>
        <translation>Použít samostatné obrázky</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="800"/>
        <source>Include files:</source>
        <translation>Zahrnout soubory:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="810"/>
        <source>Exclude files:</source>
        <translation>Vynechat soubory:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="822"/>
        <source>Recursive search depth:</source>
        <translation>Hloubka rekurzivního hledání:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="867"/>
        <location filename="../configdialog.cpp" line="354"/>
        <source>Playback</source>
        <translation>Přehrávání</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="873"/>
        <source>Continue playback on startup</source>
        <translation>Po startu pokračovat v přehrávání</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1007"/>
        <source>Replay Gain mode:</source>
        <translation>Režim úpravy zisku při přehrávání:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1024"/>
        <source>Preamp:</source>
        <translation>Předzesílení:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1056"/>
        <location filename="../forms/configdialog.ui" line="1101"/>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1069"/>
        <source>Default gain:</source>
        <translation>Výchozí zisk:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1121"/>
        <source>Use  peak info to prevent clipping</source>
        <translation>Použít informaci o vrcholu k zabránění ořezu</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1137"/>
        <source>Output:</source>
        <translation>Výstup:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1189"/>
        <source>Buffer size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1202"/>
        <source>ms</source>
        <translation type="unfinished">ms</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1238"/>
        <source>16-bit output</source>
        <translation>16bitový výstup</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1272"/>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1277"/>
        <source>Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1285"/>
        <source>Change shortcut...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="134"/>
        <source>Connectivity</source>
        <translation>Síť</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="255"/>
        <location filename="../configdialog.cpp" line="360"/>
        <source>View</source>
        <translation>Zobrazení</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="606"/>
        <source>Edit template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="752"/>
        <source>File Dialog</source>
        <translation>Souborový dialog</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="899"/>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="911"/>
        <source>Enable proxy usage</source>
        <translation>Povolit používání proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="918"/>
        <source>Proxy host name:</source>
        <translation>Adresa proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="931"/>
        <source>Proxy port:</source>
        <translation>Port proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="944"/>
        <source>Use authentication with proxy</source>
        <translation>Použít autorizaci pro proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="951"/>
        <source>Proxy user name:</source>
        <translation>Uživatelské jméno:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="964"/>
        <source>Proxy password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="209"/>
        <source>Archived skin</source>
        <translation>Sbalené téma</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="231"/>
        <source>Unarchived skin</source>
        <translation>Rozbalené téma</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="285"/>
        <source>Visualization</source>
        <translation>Vizualizace</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="275"/>
        <source>Effects</source>
        <translation>Efekty</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="295"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="143"/>
        <location filename="../forms/configdialog.ui" line="1131"/>
        <source>Audio</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1231"/>
        <source>Use software volume control</source>
        <translation>Používat softwarové ovládání hlasitosti</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="261"/>
        <source>Hide on close</source>
        <translation>Skrýt při zavření</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="268"/>
        <source>Start hidden</source>
        <translation>Spustit skryté</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="559"/>
        <source>Convert underscores to blanks</source>
        <translation>Převést podtržítka na mezery</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="566"/>
        <source>Convert %20 to blanks</source>
        <translation>Převést %20 na mezery</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="524"/>
        <source>Select Skin Files</source>
        <translation>Vybrat soubory s tématy</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="525"/>
        <source>Skin files</source>
        <translation>Soubory s tématy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="215"/>
        <source>Add...</source>
        <translation>Přidat...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="228"/>
        <source>Refresh</source>
        <translation>Obnovit</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="573"/>
        <source>Show protocol</source>
        <translation>Zobrazit protokol</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="403"/>
        <source>Transparency</source>
        <translation>Průhlednost</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="409"/>
        <source>Main window</source>
        <translation>Hlavní okno</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="432"/>
        <location filename="../forms/configdialog.ui" line="456"/>
        <location filename="../forms/configdialog.ui" line="480"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="439"/>
        <source>Equalizer</source>
        <translation>Ekvalizér</translation>
    </message>
</context>
<context>
    <name>EqWidget</name>
    <message>
        <location filename="../eqwidget.cpp" line="43"/>
        <source>Equalizer</source>
        <translation type="unfinished">Ekvalizér</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="154"/>
        <location filename="../eqwidget.cpp" line="177"/>
        <source>preset</source>
        <translation>předvolba</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="261"/>
        <source>&amp;Load/Delete</source>
        <translation>&amp;Načíst/Odstranit</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="263"/>
        <source>&amp;Save Preset</source>
        <translation>&amp;Uložit předvolbu</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="265"/>
        <source>&amp;Save Auto-load Preset</source>
        <translation>Uložit &amp;automatickou předvolbu</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="267"/>
        <source>&amp;Import</source>
        <translation>&amp;Importovat</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="270"/>
        <source>&amp;Clear</source>
        <translation>&amp;Vynulovat</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="299"/>
        <source>Saving Preset</source>
        <translation>Uložení předvolby</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="300"/>
        <source>Preset name:</source>
        <translation>Název předvolby:</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="301"/>
        <source>preset #</source>
        <translation>předvolba #</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="392"/>
        <source>Import Preset</source>
        <translation>Importovat předvolbu</translation>
    </message>
</context>
<context>
    <name>JumpToTrackDialog</name>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="53"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="54"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="55"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="84"/>
        <location filename="../jumptotrackdialog.cpp" line="135"/>
        <source>Unqueue</source>
        <translation>Vyřadit</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="70"/>
        <location filename="../jumptotrackdialog.cpp" line="86"/>
        <location filename="../jumptotrackdialog.cpp" line="137"/>
        <source>Queue</source>
        <translation>Zařadit</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="14"/>
        <source>Jump To Track</source>
        <translation>Přeskočit na skladbu</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="37"/>
        <source>Filter</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="83"/>
        <source>Refresh</source>
        <translation>Načíst znovu</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="96"/>
        <source>Jump To</source>
        <translation>Přeskočit na</translation>
    </message>
</context>
<context>
    <name>MainDisplay</name>
    <message>
        <location filename="../display.cpp" line="57"/>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="61"/>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="64"/>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="67"/>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="70"/>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="73"/>
        <source>Add file</source>
        <translation>Přidat soubor</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="80"/>
        <source>Equalizer</source>
        <translation>Ekvalizér</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="83"/>
        <source>Playlist</source>
        <translation>Seznam skladeb</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="88"/>
        <source>Repeat playlist</source>
        <translation>Opakovat seznam skladeb</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="91"/>
        <source>Shuffle</source>
        <translation>Zamíchat</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="101"/>
        <source>Volume</source>
        <translation>Hlasitost</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="107"/>
        <source>Balance</source>
        <translation>Vyvážení</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="296"/>
        <source>Volume: %1%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="300"/>
        <source>Balance: %1% right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="302"/>
        <source>Balance: %1% left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="304"/>
        <source>Balance: center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="315"/>
        <source>Seek to: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainVisual</name>
    <message>
        <location filename="../mainvisual.cpp" line="280"/>
        <source>Visualization Mode</source>
        <translation>Režim vizualizace</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="283"/>
        <source>Analyzer</source>
        <translation>Frekvenční analýza</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="284"/>
        <source>Scope</source>
        <translation>Osciloskop</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="285"/>
        <source>Off</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="292"/>
        <source>Analyzer Mode</source>
        <translation>Režim analýzy</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="295"/>
        <source>Normal</source>
        <translation>Normální</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="296"/>
        <source>Fire</source>
        <translation>Oheň</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="297"/>
        <source>Vertical Lines</source>
        <translation>Sloupce</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="298"/>
        <source>Lines</source>
        <translation>Úzké</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="299"/>
        <source>Bars</source>
        <translation>Široké</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="312"/>
        <source>Peaks</source>
        <translation>Špičky</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="316"/>
        <source>Refresh Rate</source>
        <translation>Obnovovací frekvence</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="319"/>
        <source>50 fps</source>
        <translation>50 Hz</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="320"/>
        <source>25 fps</source>
        <translation>25 Hz</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="321"/>
        <source>10 fps</source>
        <translation>10 Hz</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="322"/>
        <source>5 fps</source>
        <translation>5 Hz</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="329"/>
        <source>Analyzer Falloff</source>
        <translation>Pokles analyzátoru</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="332"/>
        <location filename="../mainvisual.cpp" line="346"/>
        <source>Slowest</source>
        <translation>Nejpomalejší</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="333"/>
        <location filename="../mainvisual.cpp" line="347"/>
        <source>Slow</source>
        <translation>Pomalý</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="334"/>
        <location filename="../mainvisual.cpp" line="348"/>
        <source>Medium</source>
        <translation>Střední</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="335"/>
        <location filename="../mainvisual.cpp" line="349"/>
        <source>Fast</source>
        <translation>Rychlý</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="336"/>
        <location filename="../mainvisual.cpp" line="350"/>
        <source>Fastest</source>
        <translation>Nejrychlejší</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="343"/>
        <source>Peaks Falloff</source>
        <translation>Pokles špiček</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="356"/>
        <source>Background</source>
        <translation>Pozadí</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="357"/>
        <source>Transparent</source>
        <translation>Průhledné</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>Choose a directory</source>
        <translation>Výběr adresáře</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Select one or more files to open</source>
        <translation>Vyberte jeden či více souborů k otevření</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>View</source>
        <translation type="unfinished">Zobrazení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <source>Playlist</source>
        <translation type="unfinished">Seznam skladeb</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Playlist Files</source>
        <translation>Seznamy skladeb</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>Open Playlist</source>
        <translation>Načíst seznam skladeb</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>Save Playlist</source>
        <translation>Uložit seznam skladeb</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>All Supported Bitstreams</source>
        <translation>Všechny podporované formáty</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <source>Tools</source>
        <translation>Nástroje</translation>
    </message>
</context>
<context>
    <name>PlayList</name>
    <message>
        <location filename="../playlist.cpp" line="204"/>
        <source>Sort List</source>
        <translation>Seřadit seznam</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="207"/>
        <location filename="../playlist.cpp" line="242"/>
        <source>By Title</source>
        <translation>Podle názvu skladby</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="211"/>
        <location filename="../playlist.cpp" line="246"/>
        <source>By Album</source>
        <translation>Podle alba</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="215"/>
        <location filename="../playlist.cpp" line="250"/>
        <source>By Artist</source>
        <translation>Podle umělce</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="219"/>
        <location filename="../playlist.cpp" line="254"/>
        <source>By Filename</source>
        <translation>Podle názvu souboru</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="223"/>
        <location filename="../playlist.cpp" line="258"/>
        <source>By Path + Filename</source>
        <translation>Podle cesty a názvu souboru</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="227"/>
        <location filename="../playlist.cpp" line="262"/>
        <source>By Date</source>
        <translation>Podle data</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="239"/>
        <source>Sort Selection</source>
        <translation>Seřadit výběr</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="274"/>
        <source>Randomize List</source>
        <translation>Zamíchat seznam</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="276"/>
        <source>Reverse List</source>
        <translation>Obrátit pořadí seznamu</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="550"/>
        <source>&amp;New PlayList</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="177"/>
        <source>&amp;Copy Selection To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="53"/>
        <source>Playlist</source>
        <translation type="unfinished">Seznam skladeb</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="231"/>
        <location filename="../playlist.cpp" line="266"/>
        <source>By Track Number</source>
        <translation>Podle čísla skladby</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="283"/>
        <source>Actions</source>
        <translation>Činnosti</translation>
    </message>
</context>
<context>
    <name>PlayListBrowser</name>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="14"/>
        <source>Playlist Browser</source>
        <translation>Prohlížeč seznamů skladeb</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="45"/>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="52"/>
        <location filename="../playlistbrowser.cpp" line="39"/>
        <source>Delete</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="69"/>
        <location filename="../forms/playlistbrowser.ui" line="79"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../playlistbrowser.cpp" line="38"/>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
</context>
<context>
    <name>PlayListSelector</name>
    <message>
        <location filename="../playlistselector.cpp" line="51"/>
        <source>&amp;Load</source>
        <translation>&amp;Načíst</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="52"/>
        <source>&amp;Save As...</source>
        <translation>Uložit j&amp;ako...</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="54"/>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="55"/>
        <source>&amp;Delete</source>
        <translation>O&amp;dstranit</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="112"/>
        <source>Rename Playlist</source>
        <translation>Přejmenovat seznam skladeb</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="112"/>
        <source>Playlist name:</source>
        <translation>Název seznamu skladeb:</translation>
    </message>
</context>
<context>
    <name>PopupSettings</name>
    <message>
        <location filename="../forms/popupsettings.ui" line="14"/>
        <source>Popup Information Settings</source>
        <translation>Nastavení informací ve vyskakovacím okně</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="75"/>
        <source>Show cover</source>
        <translation>Zobrazit obal</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="115"/>
        <source>Transparency:</source>
        <translation>Průhlednost:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="145"/>
        <source>Delay:</source>
        <translation>Prodleva:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="178"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="89"/>
        <source>Cover size:</source>
        <translation>Velikost obalu:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="29"/>
        <source>Template</source>
        <translation>Šablona</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="58"/>
        <source>Reset</source>
        <translation>Původní</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="65"/>
        <source>Insert</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="62"/>
        <source>Artist</source>
        <translation>Umělec</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="63"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="64"/>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="65"/>
        <source>Track number</source>
        <translation>Číslo stopy</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="66"/>
        <source>Two-digit track number</source>
        <translation>Dvoumístné číslo stopy</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="67"/>
        <source>Genre</source>
        <translation>Žánr</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="68"/>
        <source>Comment</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="69"/>
        <source>Composer</source>
        <translation>Skladatel</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="70"/>
        <source>Duration</source>
        <translation>Délka</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="71"/>
        <source>Disc number</source>
        <translation>Číslo disku</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="72"/>
        <source>File name</source>
        <translation>Název souboru</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="73"/>
        <source>File path</source>
        <translation>Cesta k souboru</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="74"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="75"/>
        <source>Condition</source>
        <translation>Stav</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../forms/preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Editor předvoleb</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="77"/>
        <source>Load</source>
        <translation>Načíst</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="84"/>
        <source>Delete</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="36"/>
        <source>Preset</source>
        <translation>Předvolba</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="52"/>
        <source>Auto-preset</source>
        <translation>Automatická předvolba</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="176"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Použití: qmmp [volby] [soubory]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="177"/>
        <source>Options:</source>
        <translation>Volby:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="181"/>
        <source>Don&apos;t start the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="183"/>
        <source>Print version number and exit</source>
        <translation>Vypsat číslo verze a skončit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="184"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Nápady, patche, hlášení chyb posílejte na forkotov02@hotmail.ru (anglicky)</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="182"/>
        <source>Display this text and exit</source>
        <translation>Zobrazit tento text a skončit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="71"/>
        <source>Unknown command</source>
        <translation>Neznámý příkaz</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="189"/>
        <source>QMMP version:</source>
        <translation>Verze QMMP:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="190"/>
        <source>Qt version:</source>
        <translation>Verze Qt:</translation>
    </message>
</context>
<context>
    <name>ShortcutDialog</name>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="14"/>
        <source>Change Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="43"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextScroller</name>
    <message>
        <location filename="../textscroller.cpp" line="53"/>
        <source>Autoscroll Songname</source>
        <translation>Automaticky rolovat název skladby</translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="118"/>
        <source>Buffering: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VisualMenu</name>
    <message>
        <location filename="../visualmenu.cpp" line="29"/>
        <source>Visualization</source>
        <translation>Vizualizace</translation>
    </message>
</context>
</TS>
